from flask import jsonify
from mlflow.server.handlers import catch_mlflow_exception

from mlflow_oidc_auth.store import store
from mlflow_oidc_auth.utils import check_admin_permission, get_request_param


@catch_mlflow_exception
@check_admin_permission
def create_group_prompt_regex_permission(group_name):
    store.create_group_prompt_regex_permission(
        group_name=group_name,
        regex=get_request_param("regex"),
        priority=int(get_request_param("priority")),
        permission=get_request_param("permission"),
    )
    return jsonify({"status": "success"}), 200


@catch_mlflow_exception
@check_admin_permission
def list_group_prompt_regex_permissions(group_name):
    ep = store.list_group_prompt_regex_permissions(
        group_name=group_name,
    )
    return [e.to_json() for e in ep] if ep else jsonify({"error": "No permissions found"}), 200


@catch_mlflow_exception
@check_admin_permission
def get_group_prompt_regex_permission(group_name: str, pattern_id: str):
    ep = store.get_group_prompt_regex_permission(
        group_name=group_name,
        id=int(pattern_id),
    )
    return jsonify({"prompt_permission": ep.to_json()}), 200


@catch_mlflow_exception
@check_admin_permission
def update_group_prompt_regex_permission(group_name: str, pattern_id: str):
    ep = store.update_group_prompt_regex_permission(
        group_name=group_name,
        id=int(pattern_id),
        regex=get_request_param("regex"),
        priority=int(get_request_param("priority")),
        permission=get_request_param("permission"),
    )
    return jsonify({"prompt_permission": ep.to_json()}), 200


@catch_mlflow_exception
@check_admin_permission
def delete_group_prompt_regex_permission(group_name: str, pattern_id: str):
    store.delete_group_prompt_regex_permission(
        group_name=group_name,
        id=int(pattern_id),
    )
    return jsonify({"status": "success"}), 200



from flask import jsonify
from mlflow.server.handlers import _get_tracking_store, catch_mlflow_exception

from mlflow_oidc_auth.store import store
from mlflow_oidc_auth.utils import (
    can_manage_experiment,
    check_experiment_permission,
    get_is_admin,
    get_request_param,
    get_username,
)


@catch_mlflow_exception
@check_experiment_permission
def create_group_experiment_permission(group_name: str, experiment_id: str):
    store.create_group_experiment_permission(group_name, experiment_id, get_request_param("permission"))
    return jsonify({"message": "Group experiment permission has been created."})


@catch_mlflow_exception
@check_experiment_permission
def update_group_experiment_permission(group_name: str, experiment_id: str):
    store.update_group_experiment_permission(group_name, experiment_id, get_request_param("permission"))
    return jsonify({"message": "Group experiment permission has been updated."})


@catch_mlflow_exception
@check_experiment_permission
def delete_group_experiment_permission(group_name: str, experiment_id: str):
    store.delete_group_experiment_permission(group_name, experiment_id)
    return jsonify({"message": "Group experiment permission has been deleted."})


@catch_mlflow_exception
def list_group_experiments(group_name: str):
    experiments = store.get_group_experiments(group_name)
    if get_is_admin():
        return jsonify(
            [
                {
                    "id": experiment.experiment_id,
                    "name": _get_tracking_store().get_experiment(experiment.experiment_id).name,
                    "permission": experiment.permission,
                }
                for experiment in experiments
            ]
        )
    current_user = store.get_user(get_username())
    return jsonify(
        [
            {
                "id": experiment.experiment_id,
                "name": _get_tracking_store().get_experiment(experiment.experiment_id).name,
                "permission": experiment.permission,
            }
            for experiment in experiments
            if can_manage_experiment(
                experiment.experiment_id,
                current_user.username,
            )
        ]
    )
